Summary: PAM module for GSS-API
Name: pam_gss
Version: 7.0
Release: 1.moonshot%{?dist}
License: LGPL
Group: Applications/System
URL: https://github.com/PADL/pam_gss

Source0: pam-gss.tar

BuildRequires: pam-devel, selinux-policy-devel, selinux-policy-doc
Requires(post):   /usr/sbin/semodule, /sbin/restorecon
Requires(postun): /usr/sbin/semodule, /sbin/restorecon

# Get the SELinux policy versions based on the build platform
%{!?_selinux_policy_version: %global _selinux_policy_version %(sed -e 's,.*selinux-policy-\\([^/]*\\)/.*,\\1,' /usr/share/selinux/devel/policyhelp 2>/dev/null)}
%if "%{_selinux_policy_version}" != ""
Requires:      selinux-policy >= %{_selinux_policy_version}
%endif

# Ditto
%global selinux_types %(%{__awk} '/^#[[:space:]]*SELINUXTYPE=/,/^[^#]/ { if ($3 == "-") printf "%s ", $2 }' /etc/selinux/config 2>/dev/null)
%global selinux_variants %([ -z "%{selinux_types}" ] && echo mls targeted || echo %{selinux_types})

%description
The GSS-API PAM module provides the functionality necessary to use the 
Kerberos GSS API for authentication in PAM. This module is compiled 
against the MIT Kerberos implementation.

%prep
%setup -n %{name}
mkdir SELinux
cp -p pam_gss.te SELinux/

%build
# Force compile/link options, extra security for network facing daemon
%global _hardened_build 1

# On RHEL, the KRB5 tree is under /usr, not /usr/local
make KRB5DIR=/usr
cd SELinux
for selinuxvariant in %{selinux_variants}
do
  make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile
  mv pam_gss.pp pam_gss.pp.${selinuxvariant}
  make NAME=${selinuxvariant} -f /usr/share/selinux/devel/Makefile clean
done
cd -

%install
make install DESTDIR=$RPM_BUILD_ROOT/ PAMPREFIX=%{_lib}/security/ prefix=/usr

# copy the PAM include
install -D -m644 gss-auth $RPM_BUILD_ROOT/%{_sysconfdir}/pam.d/gss-auth

# compile the SELinux policy for each policy type
for selinuxvariant in %{selinux_variants}
do
  install -D -p -m 644 SELinux/pam_gss.pp.${selinuxvariant} \
    $RPM_BUILD_ROOT/%{_datadir}/selinux/${selinuxvariant}/pam_gss.pp
done

%post
for selinuxvariant in %{selinux_variants}
do
  /usr/sbin/semodule -s ${selinuxvariant} -i \
    %{_datadir}/selinux/${selinuxvariant}/pam_gss.pp &> /dev/null || :
done

%postun
if [ $1 -eq 0 ] ; then
  for selinuxvariant in %{selinux_variants}
  do
    /usr/sbin/semodule -s ${selinuxvariant} -r pam_gss &> /dev/null || :
  done
fi

%files
%defattr(-,root,root)

# the PAM module
%attr(755,root,root) /%{_lib}/security/pam_gss.so
%attr(755,root,root) /%{_libexecdir}/pamtest
%attr(644,root,root) %config(noreplace) /etc/pam.d/gss-auth
%defattr(-,root,root,0755)
%doc SELinux/*
%{_datadir}/selinux/*/pam_gss.pp

%changelog
* Wed May  7 2014 Stefan Paetow <stefan.paetow@ja.net> - 6-3
- Tweaks to install the binary into the right location.

* Tue May  6 2014 Stefan Paetow <stefan.paetow@ja.net> - 6-2
- Includes gss-auth file for PAM.

* Fri May  2 2014 Stefan Paetow <stefan.paetow@ja.net> - 6-1
- Updated to version 6.
- Includes and installs SELinux policy.
- Tweaks to the spec.

* Thu May 1 2014 Stefan Paetow <stefan.paetow@ja.net> - 5-1
- Initial build.
